A Django app to scrape campaign-finance data from the California Secretary of State’s `CAL-ACCESS <http://www.sos.ca.gov/prd/cal-access/>`__ website

|Build Status| |PyPI version| |Documentation Status|

-  Documentation:
   `django-calaccess.californiacivicdata.org <https://django-calaccess.californiacivicdata.org>`__
-  Issues:
   `github.com/california-civic-data-coalition/django-calaccess-scraped-data/issues <https://github.com/california-civic-data-coalition/django-calaccess-scraped-data/issues>`__
-  Packaging:
   `pypi.python.org/pypi/django-calaccess-scraped-data <https://pypi.python.org/pypi/django-calaccess-scraped-data>`__
-  Testing:
   `github.com/california-civic-data-coalition/django-calaccess-scraped-data/actions <https://github.com/california-civic-data-coalition/django-calaccess-scraped-data/actions/workflows/tests.yaml>`__

.. |Build Status| image:: https://github.com/california-civic-data-coalition/django-calaccess-scraped-data/actions/workflows/tests.yaml/badge.svg
    :target: https://github.com/california-civic-data-coalition/django-calaccess-scraped-data/actions/workflows/tests.yaml
.. |PyPI version| image:: https://badge.fury.io/py/django-calaccess-scraped-data.svg
   :target: http://badge.fury.io/py/django-calaccess-scraped-data
.. |Documentation Status| image:: https://readthedocs.org/projects/django-calaccess-raw-data/badge/
   :target: http://django-calaccess.californiacivicdata.org
